# Automation-IDE  
An integrated test automation IDE developed with Python and PySide6 (Qt).  

## Components
- Editor
  - https://github.com/Integration-Automation/JEDITOR
- GUI Testing
  - https://github.com/Integration-Automation/AutoControlGUI
- API Testing
  - https://github.com/Integration-Automation/APITestka
- Web Testing
  - https://github.com/Integration-Automation/WebRunner
- Load Testing
  - https://github.com/Integration-Automation/LoadDensity
- File
  - https://github.com/Integration-Automation/FileAutomation
- OpenCV
  - https://github.com/Integration-Automation/je_opencv_wrapper
- Mail
  - https://github.com/Integration-Automation/MailThunder

## Supported features:  
- Python syntax highlighting  
- Auto reformatter  
- Code execution  
- Test scripts  
- Shell commands  
- Embedded browser  
- Jupyter integration  
- Git client  
- Code diff viewer, etc.  

## Testing modules include:  
- GUI testing  
- API testing  
- Load testing  
- Web testing  

## Installation
> pip install automation_editor

